<template>
    <div>
       <el-dialog :visible.sync="dialogVisible" :title="title" :close-on-click-modal="false" width="700px" :modal-append-to-body="false" v-if="dialogVisible">
            <el-form size="mini" :model="form" label-width="120px" ref="form" :rules="formRules">
                 <el-form-item label="应用名称：" prop="name">
                     <el-input v-model="form.name" placeholder="请输入应用名称" clearable></el-input>
                 </el-form-item>
                 <el-form-item label="应用ID：" v-show="!form.id" prop="appid">
                     <el-input v-model="form.appid" placeholder="请输入应用ID" clearable></el-input>
                 </el-form-item>
                 <el-form-item label="应用密码：" v-show="!form.id" prop="appsecret">
                     <el-input v-model="form.appsecret" placeholder="请输入应用密码" clearable></el-input>
                 </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button size="mini" @click="submit" type="primary"  :loading="loading">保存</el-button>
                <el-button size="mini" @click="dialogVisible = false">取消</el-button>
            </div>
        </el-dialog>
    </div>
</template>
<script>
import thirdPartySystemApi from '@/api/thirdPartySystem'
import { objectCopy } from '@/utils/objectCopyHelper'
export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    title: {
      type: String,
      default: '添加三方系统'
    },
    row: {
      type: Object,
      default: function () {
        return {}
      }
    }
  },
  data () {
    const limitNumType = (rule, value, callback) => {
      const reg = /[\u4e00-\u9fa5]/g // 只能输入数字和字母
      if (!value) {
        callback(new Error('请输入密码'))
      } if (reg.test(value)) {
        callback(new Error('密码不能输入中文'))
      } else {
        callback()
      }
    }
    return {
      dialogVisible: false,
      form: {
        name: null,
        appid: null,
        appsecret: null
      },
      formRules: {
        name: [{ required: true, message: '请输入应用名称', trigger: 'change' }
        ],
        appid: [
          { required: true, message: '请输入应用ID', trigger: 'change' },
          { validator: limitNumType }
        ],
        appsecret: [
          { required: true, message: '请输入应用密码', trigger: 'change' },
          { validator: limitNumType }
        ]
      },
      loading: false
    }
  },
  watch: {
    row: {
      handler (newValue, oldValue) {
        if (newValue.id) {
          this.form = objectCopy(this.row)
        }
      },
      deep: true
    },
    /**
     * 监控外部显示变量变化
     * 传递到dialog组件
     */
    show: function (newShow, oldShow) {
      this.dialogVisible = newShow
    },
    /**
     * 监控内部显示属性变化
     * 传递到外部调用变量
     */
    dialogVisible: function (newDialogShow, oldDialogShow) {
      if (!newDialogShow) {
        for (const i in this.form) {
          this.form[i] = null
        }
        this.$emit('update:show', newDialogShow)
      }
    }
  },
  methods: {
    /**
       * 提交
       */
    submit () {
      this.$refs.form.validate().then(async (res) => {
        this.loading = true
        let resData = null
        if (this.form.id) {
          const data = {
            id: this.form.id,
            name: this.form.name,
            status: this.form.status
          }
          resData = await thirdPartySystemApi.editItem(data) // 编辑
        } else {
          resData = await thirdPartySystemApi.addItem(this.form) // 新增
        }
        if (resData.code === '0') {
          this.$message({
            message: '操作成功',
            type: 'success'
          })
          this.loading = false
          this.$parent.queryData()
          this.dialogVisible = false
        } else {
          this.loading = false
        }
      })
    }
  }
}
</script>
